@@ -10,6 +10,10 @@ GOFLAGS="-X github.com/apicurio/apicurio-operators/apicurito/pkg/cmd.GitCommit=$
 GOFLAGS=$GOFLAGS" -X github.com/apicurio/apicurio-operators/apicurito/version.Version=${FUSE_VERSION}"
 GOFLAGS=$GOFLAGS" -X github.com/apicurio/apicurio-operators/apicurito/version.PriorVersion=${FUSE_PREV_VERSION}"
 
+# Updates version/version.go
+sed -i "s/Version      = .*/Version      = \"${FUSE_VERSION}\""/ version/version.go
+sed -i "s/PriorVersion = .*/PriorVersion = \"${FUSE_PREV_VERSION}\""/ version/version.go
+
 go mod vendor
 go generate ./...
 
@@ -19,5 +23,9 @@ CGO_ENABLED=0 GOOS=linux GOARCH=amd64 \
   go build -ldflags "${GOFLAGS}" \
   -o build/_output/bin/apicurito \
   -mod=vendor github.com/apicurio/apicurio-operators/apicurito/cmd/manager
+if [ $? != 0 ]; then
+  echo "Error: build failed"
+  exit 1
+fi
 
 docker build . -t $REGISTRY/$IMAGE:$TAG
